/* 

*  This file is a collection of register level E-Series functions
*  Included in this file are:
*                                DAQ_STC_Windowed_Mode_Write
*                                DAQ_STC_Windowed_Mode_Read
*				 Board_Write
*				 Board_Read
*
*  intended to work with Linux and GCC.
*  Note: this file MUST be compiled with -O to work correctly!
*
*  using typedefs to define int16, uint16, int8, uint8 in eserrlp.h

  author: Rob Butera - butera@helix.nih.gov

  28 January 1999

  Copyright (C) 1999  Robert J. Butera, Jr.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  Or visit the following URL: http://www.fsf.org/copyleft/gpl.html


*/ 


#include <unistd.h>
#include <asm/io.h>
#include "eserrlp.h"

uint16 Board_Base_Address ;

/* THERE IS NO ERROR CHECKING HERE - I assume that PNPtools has set the
   board up and we know the address!                                       

   ioperm is called to give our program permission to write to 
   Board_Base_Address through Board_Base_Address+0x1F

   value from ioperm is returned (zero if successful, -1 if not)


   Call to ioperm is not necessary if only root is going to
   to be writing (I disable this call for real time apps).
   If this call is disabled, you do not need to include unistd.h
*/

#define ADDRESS_RANGE 0x20

int Set_Board_Base_Address( uint16 base ) {

  Board_Base_Address = base ;
  return ( ioperm( Board_Base_Address, ADDRESS_RANGE, 1 ) ) ;
}


/* This function implements the STC windowed writing mode.  First *
 * the register address is written to the Window_Address_Register.*
 * The data is then written to the Window_Data_Write_Register.    *
 * Both writes are unsigned 16 bit.                               */
 
void DAQ_STC_Windowed_Mode_Write(uint16 uRegister_Address, uint16 uData)
{
	outw( uRegister_Address, Board_Base_Address+Window_Address_Register*2 );
	outw( uData, Board_Base_Address+Window_Data_Write_Register*2 ); 
}

/* This function implements the STC windowed reading mode.  First *
 * the register address is written to the Window_Address_Register.*
 * The data is then read from the Window_Data_Write_Register.     *
 * Both the read and write are unsigned 16 bit.                   */

uint16 DAQ_STC_Windowed_Mode_Read(uint16 uRegister_Address)
{
	outw( uRegister_Address, Board_Base_Address+Window_Address_Register*2);
	return( inw( Board_Base_Address+Window_Data_Read_Register*2 ) ); 
}





/* This function writes to an E-Series board register  - word     */
 
void Board_Write_Word(uint16 uRegister_Address, uint16 uData)
{
	outw(uData, Board_Base_Address+uRegister_Address);
}

/* This function reads from an E-Series board register - word       */

uint16 Board_Read_Word(uint16 uRegister_Address)
{
	return( inw( Board_Base_Address+uRegister_Address) );
}


/* 
   FOR PORTABILITY these are the same as above, only called without the _Word suffix 
   (may be eliminated - let's see how it goes)
*/
void Board_Write(uint16 uRegister_Address, uint16 uData)
{
	outw(uData, Board_Base_Address+uRegister_Address);
}

uint16 Board_Read(uint16 uRegister_Address)
{
	return( inw( Board_Base_Address+uRegister_Address) );
}



/* This function writes to an E-Series board register  - byte      */
 
void Board_Write_Byte( uint16 uRegister_Address, uint8 uData )
{
	outb( uData, Board_Base_Address+uRegister_Address );
}

/* This function reads from an E-Series board register - byte       */

uint8 Board_Read_Byte(uint16 uRegister_Address)
{
	return( inb( Board_Base_Address+uRegister_Address) );
}





